import { formatHashTag, formatImgUrl } from "@/common/fotmat";
import Counter from "@/components/counter";
import MCheckbox from "@/components/checkbox";
import { Image, Text, View } from "@tarojs/components";
import { FC, memo, useCallback } from "react";
import styles  from './index.module.scss'

type OrderParam = {
    list?: any[], 
    sale_mode?: number,
    sale_mode_name?: string,
    unit?: string,
    total_colors?: number,
    total_fabrics?: number,
    total_number?: number,
    status?: number, //订单状态
}

type Param = {
    order: OrderParam,
    onSelectChange?: (val: {color_id:number, length: number, status: true|false, sale_order_detail_id:number}) => void
}

const kindeList:FC<Param> =  memo(({order, onSelectChange}) => {
    //对应数量
    const formatCount = useCallback((item) => {
        return (order?.sale_mode == 0? item.roll : Number(item.length / 100)) + order?.unit
    }, [order])


    //checkbox选中回调
    const selectCallBack = (colorItem) => {
        console.log('colorItem::',colorItem)
        onSelectChange?.({color_id:colorItem.id, length:colorItem.length, sale_order_detail_id:colorItem.sale_order_detail_id, status: true})
    }

    //checkbox关闭回调
    const colseCallBack = (colorItem) => {
        onSelectChange?.({color_id:colorItem.id, length:colorItem.length, status: false, sale_order_detail_id:colorItem.sale_order_detail_id,})
    }

    //判断该面料下的颜色都退完了
    const colorNum = (item) => {
        return item.product_colors.some(val => {
            return val.return_roll + val.apply_return_roll == 0
        })
    }

    return (
        <View className={styles.apply_after_sales_list}>
            {order?.list?.map(item => colorNum(item)&&<View className={styles.apply_after_sales_item} >
                <View className={styles.apply_after_sales_title}>
                    <View className={styles.tag}>{order.sale_mode_name}</View>
                    <View className={styles.title}>{formatHashTag(item.code, item.name)}</View>
                </View>
                <View className={styles.color_list}>
                    {item.product_colors.map(colorItem => ((colorItem.return_roll + colorItem.apply_return_roll) == 0)&&<View className={styles.color_item}>
                        <View className={styles.image}><Image src={formatImgUrl('')}/></View>
                        <View className={styles.name_and_number}><Text>{colorItem.code + ' ' + colorItem.name}</Text><Text>x {formatCount(colorItem)}</Text></View>
                        <MCheckbox  status={item.select} onSelect={() => selectCallBack(colorItem)} onClose={() => colseCallBack(colorItem)}/>
                    </View>)}
                </View>
            </View>)}
        </View>
    )
})

export default kindeList